@@ -5,10 +5,10 @@
  * figures in LaTeX 
  *
  * Version 1.2.18
- * Last Change: September 17, 2017
+ * Last Change: March 21, 2020
  *
  * 
- * Copyright (C) 2007, 2008, 2017
+ * Copyright (C) 2007, 2008, 2017, 2020
  * Andrew D. Hwang <rot 13 nujnat at ubylpebff dot rqh>
  * Department of Mathematics and Computer Science
  * College of the Holy Cross
@@ -167,12 +167,12 @@ namespace ePiX {
 
   Complex logC(const Complex& arg, int branch)
   {
-    return Complex(0.5*log(arg.norm()), arg.Arg(branch));
+    return Complex(log(arg.norm()), arg.Arg(branch));
   }
 
   Complex sqrtC(const Complex& arg, int branch)
   {
-    double rad(arg.norm()),
+    double rad(sqrt(arg.norm())),
       th(0.5*Arg(arg));
     return Complex(rad*Cos(th), rad*Sin(th));
   }
