@@ -30,7 +30,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with ePiX; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 #include <cmath>
 #include <string>
@@ -454,7 +454,7 @@ namespace ePiX {
 		 << print((*ep).head() + shift);
 	    ++ep;
 
-	    while ((*ep).is_seen() && ep != edges.end())
+	    while (ep != edges.end() && (*ep).is_seen())
 	      obuf << path_connector() << print((*ep++).head() + shift);
 
 	    obuf << end_open_path(attribs);
